@@ -11,43 +11,13 @@ show_plot = True
 tolerance = 1/(10**8)
 
 
-def plot_model_dep(x, y_noisy, title, **kwargs):
-    file = NamedTemporaryFile().name+'.html'
-    output_file(file)
-
-    # fit a monotonic increasing function
-
-    result = trend_filter(x, y_noisy, **kwargs)
-    y_fit = result['y_fit']
-    assert isinstance(y_fit, ndarray)
-
-    plot = figure(title=title)
-    plot.circle(x, y_noisy)
-    plot.line(x, y_noisy)
-
-    plot.line(x, y_fit, color='red')
-
-    f = result['function']
-
-    # over-plot the function, showing the extrapolation too
-    xx = np.linspace(x.min() - 1, x.max() + 2, 500)
-    plot.line(xx, f(xx), color='green', line_dash='dashed')
-
-    if show_plot:
-        show(plot)
-
-    obj = result['objective_total'].value
-    print('objective %s, %s' % (obj, title))
-
-    return obj
-
-
 def test_base():
     x, y_noisy = get_example_data()
     title = 'Base model, no regularization'
     result = trend_filter(x, y_noisy)
     plot_model(result, title=title)
     obj = result['objective_total'].value
+    print('objective %s, %s' % (obj, title))
     assert obj < tolerance
 
 
@@ -57,6 +27,7 @@ def test_mono():
     result = trend_filter(x, y_noisy, monotonic=True)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
+    print('objective %s, %s' % (obj, title))
     assert abs(obj - 10.39020002241298) < tolerance
 
 
@@ -66,7 +37,8 @@ def test_l1_trend_filter():
     result = trend_filter(x, y_noisy, l_norm=1, alpha_2=0.2)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
-    assert abs(obj - 12.045109020871877) < tolerance
+    print('objective %s, %s' % (obj, title))
+    assert abs(obj - 12.044960558386068) < tolerance
 
 
 def test_l1_trend_filter_mono():
@@ -75,7 +47,8 @@ def test_l1_trend_filter_mono():
     result = trend_filter(x, y_noisy, l_norm=1, alpha_2=0.2, monotonic=True)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
-    assert abs(obj - 12.052960090588234) < tolerance
+    print('objective %s, %s' % (obj, title))
+    assert abs(obj - 12.052821372357789) < tolerance
 
 
 def test_l1_trend_filter_more_reg():
@@ -84,7 +57,8 @@ def test_l1_trend_filter_more_reg():
     result = trend_filter(x, y_noisy,  l_norm=1, alpha_2=2.0)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
-    assert abs(obj - 13.16869494642045) < tolerance
+    print('objective %s, %s' % (obj, title))
+    assert abs(obj - 13.167173504429053) < tolerance
 
 
 def test_l1_trend_filter_steps():
@@ -93,7 +67,8 @@ def test_l1_trend_filter_steps():
     result = trend_filter(x, y_noisy, l_norm=1, alpha_1=1.0, constrain_zero=True)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
-    assert abs(obj - 33.64932708644826) < tolerance
+    print('objective %s, %s' % (obj, title))
+    assert abs(obj - 33.649325762864926) < tolerance
 
 
 def test_smooth():
@@ -102,4 +77,5 @@ def test_smooth():
     result = trend_filter(x, y_noisy, l_norm=2, alpha_2=2.0)
     plot_model(result, title=title, show_extrap=True, extrap_max=3)
     obj = result['objective_total'].value
+    print('objective %s, %s' % (obj, title))
     assert abs(obj - 11.971096302251315) < tolerance
